{% load allauth %}
{% comment %} djlint:off {% endcomment %}
<{% if attrs.href %}a href="{{ attrs.href }}"{% else %}button{% endif %}
{% if attrs.form %}form="{{ attrs.form }}"{% endif %}
{% if attrs.id %}id="{{ attrs.id }}"{% endif %}
{% if attrs.name %}name="{{ attrs.name }}"{% endif %}
{% if attrs.type %}type="{{ attrs.type }}"{% endif %}
{% if attrs.value %}value="{{ attrs.value }}"{% endif %}
class="{% block class %}
    btn
    {% if "link" in attrs.tags %}btn-link
    {% else %}
      {% if "prominent" in attrs.tags %}btn-lg
      {% elif "minor" in attrs.tags %}btn-sm{% endif %}
      {% if "danger" in attrs.tags %}btn-danger
      {% elif "secondary" in attrs.tags %}btn-secondary
      {% elif "warning" in attrs.tags %}btn-warning
      {% else %}btn-primary
      {% endif %}
    {% endif %}{% endblock %}">
    {% if "tool" in attrs.tags %}
    {% if "delete" in attrs.tags %}
    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-trash" viewBox="0 0 16 16">
  <path d="M5.5 5.5A.5.5 0 0 1 6 6v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5Zm2.5 0a.5.5 0 0 1 .5.5v6a.5.5 0 0 1-1 0V6a.5.5 0 0 1 .5-.5Zm3 .5a.5.5 0 0 0-1 0v6a.5.5 0 0 0 1 0V6Z"/>
  <path d="M14.5 3a1 1 0 0 1-1 1H13v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V4h-.5a1 1 0 0 1-1-1V2a1 1 0 0 1 1-1H6a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1h3.5a1 1 0 0 1 1 1v1ZM4.118 4 4 4.059V13a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V4.059L11.882 4H4.118ZM2.5 3h11V2h-11v1Z"/>
    </svg>
    {% endif %}
    {% endif %}

{% if not "tool" in attrs.tags %}
{% slot %}
{% endslot %}
{% endif %}
</{% if attrs.href %}a{% else %}button{% endif %}>