{% if messages %}
  <div class="container fixed-top mt-5" style="max-width: 576px">
    {% for message in messages %}
      <div class="alert alert-info alert-dismissible fade show" role="alert">
        {{ message }}
        <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
      </div>
    {% endfor %}
  </div>
{% endif %}