{% extends "allauth/layouts/entrance.html" %}
{% load allauth %}

{% block head_title %}
    Too Many Requests
{% endblock head_title %}

{% block content %}
    {% element h1 %}
        Too Many Requests
    {% endelement %}
    <p>You are sending too many requests.</p>
{% endblock content %}