{% load allauth %}
{% for err in attrs.form.non_field_errors %}<div class="alert alert-danger">{{ err }}</div>{% endfor %}
<form class="{% block form_class %}{% if not attrs.no_visible_fields %}card{% endif %}{% endblock %}"
      method="{{ attrs.method }}"
      action="{{ attrs.action }}">
    {% if not attrs.no_visible_fields %}<div class="card-body">{% endif %}
        {% slot body %}
        {% endslot %}
        {% if not attrs.no_visible_fields %}</div>{% endif %}
    {% if not attrs.no_visible_fields %}<div class="card-footer">{% endif %}
        {% slot actions %}
        {% endslot %}
        {% if not attrs.no_visible_fields %}</div>{% endif %}
</form>