<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  {% include "allauth/layouts/css.html" %}
  <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">
  {% block extra_head %}{% endblock %}
  <title>{% block head_title %}{% endblock %}</title>
</head>
<body class="min-vh-100 d-flex flex-column">
  {% include "allauth/layouts/messages.html" %}
  {% block body %}
    {% block content %}{% endblock %}
  {% endblock %}
  <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
          integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz"
          crossorigin="anonymous"></script>
  {% block extra_body %}{% endblock %}
</body>
</html>