{% extends "allauth/layouts/base.html" %}
{% load i18n %}

{% block body %}
  <div class="d-flex flex-grow-1 flex-shrink-0 my-5">
    <div class="m-auto " style="max-width: 350px">
      {% block content %}{% endblock %}
    </div>
  </div>
{% endblock %}